# Changes

Version 1.1.1 (2020-02-24)

We closed a total of 14 issues (enhancements and bug fixes) through 6 pull requests, since our last release on 2019-06-29.

## Issues Closed
  - use flatten instead of setting shape directly (#34)
  - (Bug) deal with libpysal example data sets change and fix inline doctests (#30)
  - add online docs badge to readme (#28)
  - Docstrings use references to older pysal bibliography (#1)
  - spreg Documentation website (#27)
  - pysal.github.io issue #98 (#20)
  - REL: bumping version (#25)
  -  (docs, bug) change to spatial error model description for spreg.ML_Error  (#24)

## Pull Requests
  - use flatten instead of setting shape directly (#34)
  - (Bug) deal with libpysal example data sets change and fix inline doctests (#30)
  - add online docs badge to readme (#28)
  - spreg Documentation website (#27)
  - REL: bumping version (#25)
  -  (docs, bug) change to spatial error model description for spreg.ML_Error  (#24)

The following individuals contributed to this release:

  - Pedro Amaral
  - Eli Knaap
  - Wei Kang
  - James Gaboardi